# arpes.corrections.background module

**arpes.corrections.background.remove\_incoherent\_background(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
set\_zero=True)**

> Sometimes spectra are contaminated by data above the Fermi level for
> various reasons (such as broad core levels from 2nd harmonic light, or
> slow enough electrons in ToF experiments to be counted in subsequent
> pulses). :param data: :param set\_zero: :return:
